Learn R Programming

ivx (version 1.1.0)

ivx-package: Robust Econometric Inference

Description

Drawing statistical inference on the coefficients of a short- or long-horizon predictive regression with persistent regressors by using the IVX method of Magdalinos and Phillips (2009) and Kostakis, Magdalinos and Stamatogiannis (2015).

Arguments

Author

Maintainer: Kostas Vasilopoulos k.vasilopoulo@gmail.com

Authors:

See Also