vector of observations of length n, or a matrix with
n rows.
x
design matrix of dimension n * p.
horizon
is the horizon (default horizon = 1 corresponds to a
short-horizon regression).
offset
(numeric of length n). This can be used to
specify an a priori known component to be included in the
linear predictor during fitting.
...
currently disregarded.
w
vector of weights (length n) to be used in the fitting
process for the wfit functions. Weighted least squares is
used with weights w, i.e., sum(w * e^2) is minimized.