vcov.ivx: Calculate Variance-Covariance Matrix for a Fitted Model Object
Description
Calculate Variance-Covariance Matrix for a Fitted Model Object
Usage
# S3 method for ivx
vcov(object, complete = TRUE, ...)
# S3 method for summary.ivx
vcov(object, complete = TRUE, ...)
Value
A matrix of the estimated covariances between the parameter estimates
of the model. This should have row and column names corresponding to the
parameter names given by the coef method.
Arguments
object
a fitted ivx and summary.ivx object.
complete
logical indicating if the full variance-covariance matrix
should be returned. When complete = TRUE, vcov() is compatible with coef().